@@ -8,14 +8,14 @@ import py.path
 
 import _pytest.pytester as pytester
 import pytest
+from _pytest.config import ExitCode
 from _pytest.config import PytestPluginManager
-from _pytest.main import ExitCode
-from _pytest.outcomes import Failed
 from _pytest.pytester import CwdSnapshot
 from _pytest.pytester import HookRecorder
 from _pytest.pytester import LineMatcher
 from _pytest.pytester import SysModulesSnapshot
 from _pytest.pytester import SysPathsSnapshot
+from _pytest.pytester import Testdir
 
 
 def test_make_hook_recorder(testdir) -> None:
@@ -89,6 +89,29 @@ def test_testdir_runs_with_plugin(testdir) -> None:
     result.assert_outcomes(passed=1)
 
 
+def test_testdir_with_doctest(testdir):
+    """Check that testdir can be used within doctests.
+
+    It used to use `request.function`, which is `None` with doctests."""
+    testdir.makepyfile(
+        **{
+            "sub/t-doctest.py": """
+        '''
+        >>> import os
+        >>> testdir = getfixture("testdir")
+        >>> str(testdir.makepyfile("content")).replace(os.sep, '/')
+        '.../basetemp/sub.t-doctest0/sub.py'
+        '''
+    """,
+            "sub/__init__.py": "",
+        }
+    )
+    result = testdir.runpytest(
+        "-p", "pytester", "--doctest-modules", "sub/t-doctest.py"
+    )
+    assert result.ret == 0
+
+
 def test_runresult_assertion_on_xfail(testdir) -> None:
     testdir.makepyfile(
         """
@@ -170,7 +193,7 @@ def test_hookrecorder_basic(holder) -> None:
     call = rec.popcall("pytest_xyz")
     assert call.arg == 123
     assert call._name == "pytest_xyz"
-    pytest.raises(Failed, rec.popcall, "abc")
+    pytest.raises(pytest.fail.Exception, rec.popcall, "abc")
     pm.hook.pytest_xyz_noarg()
     call = rec.popcall("pytest_xyz_noarg")
     assert call._name == "pytest_xyz_noarg"
@@ -273,7 +296,8 @@ def test_assert_outcomes_after_pytest_error(testdir) -> None:
         result.assert_outcomes(passed=0)
 
 
-def test_cwd_snapshot(tmpdir) -> None:
+def test_cwd_snapshot(testdir: Testdir) -> None:
+    tmpdir = testdir.tmpdir
     foo = tmpdir.ensure("foo", dir=1)
     bar = tmpdir.ensure("bar", dir=1)
     foo.chdir()
@@ -456,22 +480,31 @@ def test_testdir_run_timeout_expires(testdir) -> None:
 
 def test_linematcher_with_nonlist() -> None:
     """Test LineMatcher with regard to passing in a set (accidentally)."""
-    lm = LineMatcher([])
+    from _pytest._code.source import Source
 
-    with pytest.raises(AssertionError):
-        lm.fnmatch_lines(set())
-    with pytest.raises(AssertionError):
-        lm.fnmatch_lines({})
+    lm = LineMatcher([])
+    with pytest.raises(TypeError, match="invalid type for lines2: set"):
+        lm.fnmatch_lines(set())  # type: ignore[arg-type]  # noqa: F821
+    with pytest.raises(TypeError, match="invalid type for lines2: dict"):
+        lm.fnmatch_lines({})  # type: ignore[arg-type]  # noqa: F821
+    with pytest.raises(TypeError, match="invalid type for lines2: set"):
+        lm.re_match_lines(set())  # type: ignore[arg-type]  # noqa: F821
+    with pytest.raises(TypeError, match="invalid type for lines2: dict"):
+        lm.re_match_lines({})  # type: ignore[arg-type]  # noqa: F821
+    with pytest.raises(TypeError, match="invalid type for lines2: Source"):
+        lm.fnmatch_lines(Source())  # type: ignore[arg-type]  # noqa: F821
     lm.fnmatch_lines([])
     lm.fnmatch_lines(())
-
-    assert lm._getlines({}) == {}
-    assert lm._getlines(set()) == set()
+    lm.fnmatch_lines("")
+    assert lm._getlines({}) == {}  # type: ignore[arg-type,comparison-overlap]  # noqa: F821
+    assert lm._getlines(set()) == set()  # type: ignore[arg-type,comparison-overlap]  # noqa: F821
+    assert lm._getlines(Source()) == []
+    assert lm._getlines(Source("pass\npass")) == ["pass", "pass"]
 
 
 def test_linematcher_match_failure() -> None:
     lm = LineMatcher(["foo", "foo", "bar"])
-    with pytest.raises(Failed) as e:
+    with pytest.raises(pytest.fail.Exception) as e:
         lm.fnmatch_lines(["foo", "f*", "baz"])
     assert e.value.msg is not None
     assert e.value.msg.splitlines() == [
@@ -484,7 +517,7 @@ def test_linematcher_match_failure() -> None:
     ]
 
     lm = LineMatcher(["foo", "foo", "bar"])
-    with pytest.raises(Failed) as e:
+    with pytest.raises(pytest.fail.Exception) as e:
         lm.re_match_lines(["foo", "^f.*", "baz"])
     assert e.value.msg is not None
     assert e.value.msg.splitlines() == [
@@ -497,8 +530,28 @@ def test_linematcher_match_failure() -> None:
     ]
 
 
+def test_linematcher_consecutive():
+    lm = LineMatcher(["1", "", "2"])
+    with pytest.raises(pytest.fail.Exception) as excinfo:
+        lm.fnmatch_lines(["1", "2"], consecutive=True)
+    assert str(excinfo.value).splitlines() == [
+        "exact match: '1'",
+        "no consecutive match: '2'",
+        "   with: ''",
+    ]
+
+    lm.re_match_lines(["1", r"\d?", "2"], consecutive=True)
+    with pytest.raises(pytest.fail.Exception) as excinfo:
+        lm.re_match_lines(["1", r"\d", "2"], consecutive=True)
+    assert str(excinfo.value).splitlines() == [
+        "exact match: '1'",
+        r"no consecutive match: '\\d'",
+        "    with: ''",
+    ]
+
+
 @pytest.mark.parametrize("function", ["no_fnmatch_line", "no_re_match_line"])
-def test_no_matching(function) -> None:
+def test_linematcher_no_matching(function) -> None:
     if function == "no_fnmatch_line":
         good_pattern = "*.py OK*"
         bad_pattern = "*X.py OK*"
@@ -519,7 +572,7 @@ def test_no_matching(function) -> None:
 
     # check the function twice to ensure we don't accumulate the internal buffer
     for i in range(2):
-        with pytest.raises(Failed) as e:
+        with pytest.raises(pytest.fail.Exception) as e:
             func = getattr(lm, function)
             func(good_pattern)
         obtained = str(e.value).splitlines()
@@ -546,25 +599,23 @@ def test_no_matching(function) -> None:
     func(bad_pattern)  # bad pattern does not match any line: passes
 
 
-def test_no_matching_after_match() -> None:
+def test_linematcher_no_matching_after_match() -> None:
     lm = LineMatcher(["1", "2", "3"])
     lm.fnmatch_lines(["1", "3"])
-    with pytest.raises(Failed) as e:
+    with pytest.raises(pytest.fail.Exception) as e:
         lm.no_fnmatch_line("*")
     assert str(e.value).splitlines() == ["fnmatch: '*'", "   with: '1'"]
 
 
-def test_pytester_addopts(request, monkeypatch) -> None:
+def test_pytester_addopts_before_testdir(request, monkeypatch) -> None:
+    orig = os.environ.get("PYTEST_ADDOPTS", None)
     monkeypatch.setenv("PYTEST_ADDOPTS", "--orig-unused")
-
     testdir = request.getfixturevalue("testdir")
-
-    try:
-        assert "PYTEST_ADDOPTS" not in os.environ
-    finally:
-        testdir.finalize()
-
-    assert os.environ["PYTEST_ADDOPTS"] == "--orig-unused"
+    assert "PYTEST_ADDOPTS" not in os.environ
+    testdir.finalize()
+    assert os.environ.get("PYTEST_ADDOPTS") == "--orig-unused"
+    monkeypatch.undo()
+    assert os.environ.get("PYTEST_ADDOPTS") == orig
 
 
 def test_run_stdin(testdir) -> None:
@@ -644,14 +695,10 @@ def test_popen_default_stdin_stderr_and_stdin_None(testdir) -> None:
 
 
 def test_spawn_uses_tmphome(testdir) -> None:
-    import os
-
     tmphome = str(testdir.tmpdir)
+    assert os.environ.get("HOME") == tmphome
 
-    # Does use HOME only during run.
-    assert os.environ.get("HOME") != tmphome
-
-    testdir._env_run_update["CUSTOMENV"] = "42"
+    testdir.monkeypatch.setenv("CUSTOMENV", "42")
 
     p1 = testdir.makepyfile(
         """
@@ -708,3 +755,13 @@ def test_testdir_outcomes_with_multiple_errors(testdir):
     result.assert_outcomes(error=2)
 
     assert result.parseoutcomes() == {"error": 2}
+
+
+def test_makefile_joins_absolute_path(testdir: Testdir) -> None:
+    absfile = testdir.tmpdir / "absfile"
+    if sys.platform == "win32":
+        with pytest.raises(OSError):
+            testdir.makepyfile(**{str(absfile): ""})
+    else:
+        p1 = testdir.makepyfile(**{str(absfile): ""})
+        assert str(p1) == (testdir.tmpdir / absfile) + ".py"
